pub struct InteractBlockMessage {
pub client: Entity,
pub hand: Hand,
pub position: BlockPos,
pub face: Direction,
pub cursor_pos: Vec3,
pub head_inside_block: bool,
pub sequence: i32,
}Fields
client: Entityhand: HandThe hand that was used
position: BlockPosThe location of the block that was interacted with
face: DirectionThe face of the block that was clicked
cursor_pos: Vec3The position inside of the block that was clicked on
head_inside_block: boolWhether or not the player’s head is inside a block
sequence: i32Sequence number for synchronization